(ns-node? zloc)True if the node at this location is a namespace declaration.
True if the node at this location is a namespace declaration.
(rewrite-ns-form zloc opts)Insert appropriate line breaks and indentation before each ns child form.
Insert appropriate line breaks and indentation before each ns child form.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |